
use std::io::Read;

pub fn startup(json: &crate::json::JsonStruct) -> (curl::easy::Easy, String) {
    // escape character for { is {{ and for } is }}
    let data = format!("{{\"entity_id\": {}}}", &json.light_entity_id);
    let auth = format!("Authorization: Bearer {}", &json.access_token[1..json.access_token.len()-1]);

    let mut list = curl::easy::List::new();
    list.append(&auth).expect("[ERROR] Failed to set the authentication token");
    list.append("Content-Type: application/json").unwrap();

    let mut request = curl::easy::Easy::new();

    request.url(&json.ha_url[1..&json.ha_url.len()-1]).expect("[ERROR] Failed to set the URL for the CURL request");
    request.post(true).expect("[ERROR] Failed to set the CURL request as POST");
    request.http_headers(list).expect("ERROR] Failed to apply HTTP headers");
    request.post_field_size(data.len() as u64).expect("[ERROR] Failed to set the POST field size for CURL request");

    (request, data)
}
pub fn request(request: &mut curl::easy::Easy, data: &str) -> Result<u32, curl::Error> {
    let mut transfer = request.transfer();
    
    if let Err(e) = transfer.read_function(|buf| {
        Ok(data.as_bytes().read(buf).unwrap_or(0))
    }) {
        eprintln!("[ERROR] Failed to read the data:\n{e}");
        return Err(e);
    }

    if let Err(e) = transfer.perform() {
        eprintln!("[ERROR] Failed to perform the CURL request:\n{e}");
        return Err(e);
    }
    
    // drop transfer so we can access request.response_code below
    drop(transfer);
    
    match request.response_code() { 
        Ok(t) => Ok(t),
        Err(e) => {
            eprintln!("[ERROR] Failed to retrieve the response code:\n{e}");
            Err(e)
        },
    }
}